@@ -1,6 +1,9 @@
 package Tcl::pTk::Bitmap;
 
-our ($VERSION) = ('1.05');
+our ($VERSION) = ('1.06');
+
+use warnings;
+use strict;
 
 require Tcl::pTk;
 require Tcl::pTk::Image;
