@@ -1,6 +1,9 @@
 package Tcl::pTk::Menubutton;
 
-our ($VERSION) = ('1.05');
+our ($VERSION) = ('1.06');
+
+use warnings;
+use strict;
 
 # Simple Menu package.
 
