@@ -11,7 +11,10 @@
 
 package Tcl::pTk::TextEdit;
 
-our ($VERSION) = ('1.05');
+our ($VERSION) = ('1.06');
+
+use warnings;
+use strict;
 
 use Tcl::pTk qw (Ev);
 use AutoLoader;
