@@ -1,5 +1,8 @@
 # colors.pl
 
+use warnings;
+use strict;
+
 use vars qw/$TOP/;
 
 sub colors {
